@@ -2,7 +2,7 @@
 
 package Command::Do;
 {
-    $Command::Do::VERSION = '0.09';
+    $Command::Do::VERSION = '0.10';
 }
 
 BEGIN {
@@ -17,7 +17,7 @@ BEGIN {
 use Validation::Class;
 use Validation::Class::Exporter;
 
-our $VERSION = '0.09';    # VERSION
+our $VERSION = '0.10';    # VERSION
 
 Validation::Class::Exporter->apply_spec(settings => [base => ['Command::Do']]);
 
@@ -76,7 +76,6 @@ dir optspec => sub {1};             #noop
 1;
 
 __END__
-
 =pod
 
 =head1 NAME
@@ -85,36 +84,35 @@ Command::Do - The power of the Sun in the palm of your hand
 
 =head1 VERSION
 
-version 0.09
+version 0.10
 
 =head1 SYNOPSIS
 
 in yourcmd:
 
     use YourCmd;
-    YourCmd->run;
+    YourCmd->new->run;
 
 in lib/YourCmd.pm
 
     package YourCmd;
-    
     use Command::Do;
-    
+
     fld name => {
         required => 1,
         alias    => 'n',
         optspec  => '=s'
     };
-    
+
     mth run => {
-        
+
         input => ['name'],
         using => sub {
-            
+
             exit print "You sure have a nice name, ", shift->name, "\n";
-            
+
         }
-        
+
     };
 
 and, finally, at the command line:
@@ -136,31 +134,31 @@ configuration and its dependencies are trivial.
 
     package yourcmd;
     use Command::Do;
-    
+
     mixin all  => {
         filters => [qw/trim strip/]
     };
-    
+
     field file => {
         mixin   => 'all',
         optspec => 's@', # 100% Getopt::Long Compliant
         alias   => ['f'] # directive is attached to the option spec
-    }; 
-    
+    };
+
     # self-validating routines
     method run => {
-    
+
         input => ['file'],
         using => sub {
-            
+
             # because the opt_spec is s@, file is always an array
             exit print join "\n", @{shift->file};
-            
+
         }
-        
+
     };
-    
-    yourcmd->run;
+
+    yourcmd->new->run;
 
 ... sometimes you need a suite of commands:
 
@@ -170,50 +168,50 @@ configuration and its dependencies are trivial.
     {
         # each command is independent and can invoke sub-classes
         classes => 1, # loads and registers yourcmd::*
-        
+
     };
-    
+
     # pass args to children
     Getopt::Long::Configure(qw(pass_through));
-    
+
     # the child command
     fld command => {
-    
+
         required   => 1,
         min_length => 2,
         filters    => ['trim', 'strip', sub { $_[0] =~ s/\W/\_/g; $_[0] }]
-    
+
     };
-    
+
     # happens at instantiation
     build sub {
-        
+
         my $self = shift;
-        
+
         $self->command(shift @ARGV);
-        
+
         return $self;
-        
+
     };
-    
+
     sub run {
-    
+
         my $self = shift;
-        
+
         my $command = $self->command;
-        
+
         die $self->error_to_string("\n") unless $command;
-        
+
         # invokes child command using the class method ...
         # see Validation::Class
-        
+
         my $subcmd = $self->class($command); # load lib/YourCmd/SubCmd.pm
-        
+
         return $subcmd->run;
-        
+
     };
-    
-    yourcmd->run;
+
+    yourcmd->new->run;
 
 Please note: Command::Do is very minimalistic and tries to remain unassuming,
 each class field (see L<Validation::Class>) that is to be used as a command line
@@ -223,12 +221,12 @@ are deduced from the field name and alias directive.
 
     package MyCommand;
     use Command::Do;
-    
+
     field verbose => {
         optspec => '', # sets flag, same as '!'
         alias   => 'v'
     };
-    
+
     # this is the equivalent to the following Getopt::Long statement
     # GetOptions('verbose|v!' => \$variable);
 
@@ -236,7 +234,7 @@ Furthermore, in addition to being a class that represents a command that does
 stuff, Command::Do is also described as follows:
 
     com-man-do: A soldier specially trained to carry out raids.
-    
+
     In English, the term commando means a specific kind of individual soldier or
     military unit. In contemporary usage, commando usually means elite light
     infantry and/or special operations forces units, specializing in amphibious
